%
% labreport.cls
%
% Class file for EEL 4712 (Digital Design) lab reports.
%
% Mark Shroyer <mshroyer@ufl.edu>
%

% Declare class information
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{labreport}[2007/01/29 Mark Shroyer]

% Allow the draft option to be passed to the article class.
\DeclareOption{draft}{\PassOptionsToClass{\CurrentOption}{article}}
% Add the left equation numbering and title page options to the article class.
\PassOptionsToClass{leqno,titlepage}{article}
\ProcessOptions

% Load the base class and the required packages.
\LoadClass{article}
\RequirePackage{labreport}

% Set custom paper size.
\usepackage[letterpaper,left=3cm,right=3cm,top=3cm,bottom=3cm]{geometry}

% Load the graphics package with specific options, conditional on
% whether this document is being processed by latex or pdflatex.
\ifx\pdftexversion\undefined
    \RequirePackage[dvips,final]{graphicx}
\else
    \RequirePackage[pdftex,final]{graphicx}
\fi

% Allow us to use pdftex_t xfig exports, among other things.
\RequirePackage{color}
\RequirePackage{epsfig}

% Overload the maketitle command to conform to Dr. Lam's specifications.
\renewcommand\maketitle{\begin{titlepage}%
  \let\footnotesize\small
  \let\footnoterule\relax
  \let \footnote \thanks
  \null\vfil
  \vskip 54\p@
  \begin{center}%
    {\LARGE \@title \par}%
    \vskip 2em%
    % \teamname
    {\large
     \lineskip .75em%
      \begin{tabular}[t]{c}%
        \@author
      \end{tabular}\par}%
      \vskip 1.5em%
      {\large \@coursenum\@labsection}\par%
    {\large \@labtime \@date}\par%       % Set date in \large size.
      \@labta%
  \end{center}\par
  \@thanks
  \vfil\null
  \end{titlepage}%
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}

% Define commands to set extended parameters for this modified title page.
\newcommand{\@coursenum}{EEL~4712}
\newcommand{\coursenum}[1]{\renewcommand{\@coursenum}{#1}}
\newcommand{\@labtime}{}
\newcommand{\labtime}[1]{\renewcommand{\@labtime}{#1: }}
\newcommand{\@labsection}{}
\newcommand{\labsection}[1]{\renewcommand{\@labsection}{ Section #1}}
\newcommand{\@labta}{}
\newcommand{\labta}[1]{\renewcommand{\@labta}{\par \large TA: #1}}

% Enable PDF bookmarks and reference hyperlinks. In order to ensure proper
% operation, this should be the last package loaded during typesetting.
\usepackage[bookmarksopen=true]{hyperref}
